0.2.0 (2024-01-04)
==================

Features
--------

- Basic checking functionality has been implemented, comprising three rules. (https://github.com/nathanjmcdougall/suiteas/issues/30)


0.1.0 (2023-11-05)
==================

Features
--------

- The project has been initialized as a skeleton using `rye`. (https://github.com/nathanjmcdougall/suiteas/issues/3)
- Changelogs with `towncrier`` have been configured for this project. (https://github.com/nathanjmcdougall/suiteas/issues/4)
- The PyPI release process has been configured. (https://github.com/nathanjmcdougall/suiteas/issues/5)
- `pre-commit` has been configured for this project with basic hooks. (https://github.com/nathanjmcdougall/suiteas/issues/6)
